@@ -13,7 +13,7 @@ uncode <- function(df, invert = FALSE, db = "NASIS", stringsAsFactors = default.
     ORDER BY DomainID, ColumnPhysicalName, ChoiceValue;"
     
     # setup connection local NASIS
-    channel <- RODBC::odbcDriverConnect(connection = "DSN=nasis_local; UID=NasisSqlRO; PWD=nasisRe@d0n1y")
+    channel <- RODBC::odbcDriverConnect(connection = getOption('soilDB.NASIS.credentials'))
     
     # exec query
     d <- RODBC::sqlQuery(channel, q, stringsAsFactors = FALSE)
